@@ -24,11 +24,12 @@
 #include <config.h>
 #endif
 
+#include "gedit-commands.h"
+
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
-#include "gedit-commands.h"
 #include "gedit-window.h"
 #include "gedit-window-private.h"
 #include "gedit-notebook.h"
@@ -52,6 +53,9 @@ static void tab_state_changed_while_saving (GeditTab    *tab,
 					    GParamSpec  *pspec,
 					    GeditWindow *window);
 
+static void save_as_tab (GeditTab    *tab,
+			 GeditWindow *window);
+
 void
 _gedit_cmd_file_new (GSimpleAction *action,
                      GVariant      *parameter,
@@ -68,40 +72,39 @@ static GeditTab *
 get_tab_from_file (GList *docs,
 		   GFile *file)
 {
-	GeditTab *tab = NULL;
+	GList *l;
 
-	while (docs != NULL)
+	for (l = docs; l != NULL; l = l->next)
 	{
-		GeditDocument *d;
+		GeditDocument *doc;
 		GtkSourceFile *source_file;
-		GFile *l;
+		GFile *location;
 
-		d = GEDIT_DOCUMENT (docs->data);
-		source_file = gedit_document_get_file (d);
+		doc = l->data;
+		source_file = gedit_document_get_file (doc);
+		location = gtk_source_file_get_location (source_file);
 
-		l = gtk_source_file_get_location (source_file);
-		if (l != NULL && g_file_equal (l, file))
+		if (location != NULL && g_file_equal (location, file))
 		{
-			tab = gedit_tab_get_from_document (d);
-			break;
+			return gedit_tab_get_from_document (doc);
 		}
-
-		docs = g_list_next (docs);
 	}
 
-	return tab;
+	return NULL;
 }
 
 static gboolean
 is_duplicated_file (GSList *files,
 		    GFile  *file)
 {
-	while (files != NULL)
-	{
-		if (g_file_equal (files->data, file))
-			return TRUE;
+	GSList *l;
 
-		files = g_slist_next (files);
+	for (l = files; l != NULL; l = l->next)
+	{
+		if (g_file_equal (l->data, file))
+		{
+			return TRUE;
+		}
 	}
 
 	return FALSE;
@@ -116,11 +119,11 @@ load_file_list (GeditWindow             *window,
 		gint                     column_pos,
 		gboolean                 create)
 {
-	GeditTab *tab;
-	GSList *loaded_files = NULL; /* Number of files to load */
-	gboolean jump_to = TRUE; /* Whether to jump to the new tab */
 	GList *win_docs;
 	GSList *files_to_load = NULL;
+	GSList *loaded_files = NULL;
+	GeditTab *tab;
+	gboolean jump_to = TRUE; /* Whether to jump to the new tab */
 	const GSList *l;
 	gint num_loaded_files = 0;
 
@@ -128,17 +131,25 @@ load_file_list (GeditWindow             *window,
 
 	win_docs = gedit_window_get_documents (window);
 
-	/* Remove the uris corresponding to documents already open
-	 * in "window" and remove duplicates from "uris" list */
+	/* Remove the files corresponding to documents already opened in
+	 * "window" and remove duplicates from the "files" list.
+	 */
 	for (l = files; l != NULL; l = l->next)
 	{
-		if (is_duplicated_file (files_to_load, l->data))
+		GFile *file = l->data;
+
+		if (is_duplicated_file (files_to_load, file))
 		{
 			continue;
 		}
 
-		tab = get_tab_from_file (win_docs, l->data);
-		if (tab != NULL)
+		tab = get_tab_from_file (win_docs, file);
+
+		if (tab == NULL)
+		{
+			files_to_load = g_slist_prepend (files_to_load, file);
+		}
+		else
 		{
 			if (l == files)
 			{
@@ -169,11 +180,6 @@ load_file_list (GeditWindow             *window,
 			loaded_files = g_slist_prepend (loaded_files,
 			                                gedit_tab_get_document (tab));
 		}
-		else
-		{
-			files_to_load = g_slist_prepend (files_to_load,
-							 l->data);
-		}
 	}
 
 	g_list_free (win_docs);
@@ -194,7 +200,7 @@ load_file_list (GeditWindow             *window,
 		doc = gedit_tab_get_document (tab);
 
 		if (gedit_document_is_untouched (doc) &&
-		    (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_NORMAL))
+		    gedit_tab_get_state (tab) == GEDIT_TAB_STATE_NORMAL)
 		{
 			_gedit_tab_load (tab,
 					 l->data,
@@ -217,7 +223,7 @@ load_file_list (GeditWindow             *window,
 
 	while (l != NULL)
 	{
-		g_return_val_if_fail (l->data != NULL, 0);
+		g_return_val_if_fail (l->data != NULL, NULL);
 
 		tab = gedit_window_create_tab_from_location (window,
 							     l->data,
@@ -262,13 +268,12 @@ load_file_list (GeditWindow             *window,
 	{
 		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
 					       window->priv->generic_message_cid,
-					       ngettext("Loading %d file\342\200\246",
-							"Loading %d files\342\200\246",
-							num_loaded_files),
+					       ngettext ("Loading %d file\342\200\246",
+							 "Loading %d files\342\200\246",
+							 num_loaded_files),
 					       num_loaded_files);
 	}
 
-	/* Free uris_to_load. Note that l points to the first element of uris_to_load */
 	g_slist_free (files_to_load);
 
 	return loaded_files;
@@ -277,12 +282,12 @@ load_file_list (GeditWindow             *window,
 /**
  * gedit_commands_load_location:
  * @window: a #GeditWindow
- * @location: a #GFile to be loaded
+ * @location: a #GFile to load
  * @encoding: (allow-none): the #GtkSourceEncoding of @location
- * @line_pos: the line position to place the cursor when @location is loaded
- * @column_pos: the line column to place the cursor when @location is loaded
+ * @line_pos: the line position to place the cursor
+ * @column_pos: the line column to place the cursor
  *
- * Loads @location. Ignores non-existing locations
+ * Loads @location. Ignores non-existing locations.
  */
 void
 gedit_commands_load_location (GeditWindow             *window,
@@ -314,14 +319,15 @@ gedit_commands_load_location (GeditWindow             *window,
 /**
  * gedit_commands_load_locations:
  * @window: a #GeditWindow
- * @locations: (element-type Gio.File): the locations to be loaded
- * @encoding: (allow-none): the #GtkSourceEncoding of @location
- * @line_pos: the line position to place the cursor when @location is loaded
- * @column_pos: the line column to place the cursor when @location is loaded
+ * @locations: (element-type Gio.File): the locations to load
+ * @encoding: (allow-none): the #GtkSourceEncoding
+ * @line_pos: the line position to place the cursor
+ * @column_pos: the line column to place the cursor
  *
- * Loads @locations. Ignore non-existing locations
+ * Loads @locations. Ignore non-existing locations.
  *
- * Returns: (element-type Gedit.Document) (transfer container): the locations that were loaded
+ * Returns: (element-type Gedit.Document) (transfer container): the locations
+ * that were loaded.
  */
 GSList *
 gedit_commands_load_locations (GeditWindow             *window,
@@ -330,8 +336,8 @@ gedit_commands_load_locations (GeditWindow             *window,
 			       gint                     line_pos,
 			       gint                     column_pos)
 {
-	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
-	g_return_val_if_fail ((locations != NULL) && (locations->data != NULL), 0);
+	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
+	g_return_val_if_fail (locations != NULL && locations->data != NULL, NULL);
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -340,7 +346,7 @@ gedit_commands_load_locations (GeditWindow             *window,
 
 /*
  * From the command line we can specify a line position for the
- * first doc. Beside specifying a not existing uri creates a
+ * first doc. Beside specifying a non-existing file creates a
  * titled document.
  */
 GSList *
@@ -380,7 +386,6 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 	if (response_id != GTK_RESPONSE_OK)
 	{
 		gedit_file_chooser_dialog_destroy (dialog);
-
 		return;
 	}
 
@@ -401,7 +406,7 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 	}
 
 	/* Remember the folder we navigated to */
-	 _gedit_window_set_default_location (window, files->data);
+	_gedit_window_set_default_location (window, files->data);
 
 	loaded = gedit_commands_load_locations (window,
 	                                        files,
@@ -423,7 +428,7 @@ _gedit_cmd_file_open (GSimpleAction *action,
 
 	if (GEDIT_IS_WINDOW (user_data))
 	{
-		window = GEDIT_WINDOW (user_data);
+		window = user_data;
 	}
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -443,13 +448,14 @@ _gedit_cmd_file_open (GSimpleAction *action,
 			return;
 		}
 
+		/* FIXME: this should be in GeditWindow. */
 		gtk_widget_hide (GTK_WIDGET (window->priv->open_document_popover));
 		gtk_widget_hide (GTK_WIDGET (window->priv->fullscreen_open_document_popover));
 	}
 
-	/* Translators: "Open" is the title of the file chooser window */
+	/* Translators: "Open" is the title of the file chooser window. */
 	open_dialog = gedit_file_chooser_dialog_create (_("Open"),
-							window ? GTK_WINDOW (window) : NULL,
+							window != NULL ? GTK_WINDOW (window) : NULL,
 							GEDIT_FILE_CHOOSER_OPEN |
 							GEDIT_FILE_CHOOSER_ENABLE_ENCODING |
 							GEDIT_FILE_CHOOSER_ENABLE_DEFAULT_FILTERS,
@@ -462,6 +468,9 @@ _gedit_cmd_file_open (GSimpleAction *action,
 		GeditDocument *doc;
 		GFile *default_path = NULL;
 
+		/* The file chooser dialog for opening files is not modal, so
+		 * ensure that at most one file chooser is opened.
+		 */
 		g_object_set_data (G_OBJECT (window),
 				   GEDIT_OPEN_DIALOG_KEY,
 				   open_dialog);
@@ -470,7 +479,7 @@ _gedit_cmd_file_open (GSimpleAction *action,
 				   (GWeakNotify) open_dialog_destroyed,
 				   window);
 
-		/* Set the current folder uri */
+		/* Set the current folder */
 		doc = gedit_window_get_active_document (window);
 
 		if (doc != NULL)
@@ -485,7 +494,9 @@ _gedit_cmd_file_open (GSimpleAction *action,
 		}
 
 		if (default_path == NULL)
+		{
 			default_path = _gedit_window_get_default_location (window);
+		}
 
 		if (default_path != NULL)
 		{
@@ -504,8 +515,8 @@ _gedit_cmd_file_open (GSimpleAction *action,
 
 void
 _gedit_cmd_file_reopen_closed_tab (GSimpleAction *action,
-                                   GVariant      *parameter,
-                                   gpointer      user_data)
+				   GVariant      *parameter,
+				   gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GFile *file;
@@ -596,7 +607,7 @@ replace_read_only_file (GtkWindow *parent,
 
 	gtk_widget_destroy (dialog);
 
-	return (ret == GTK_RESPONSE_YES);
+	return ret == GTK_RESPONSE_YES;
 }
 
 static gboolean
@@ -656,7 +667,6 @@ change_compression (GtkWindow *parent,
 		button_label = _("_Save As Plain Text");
 	}
 
-
 	g_free (name_for_display);
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
@@ -673,7 +683,7 @@ change_compression (GtkWindow *parent,
 
 	gtk_widget_destroy (dialog);
 
-	return (ret == GTK_RESPONSE_YES);
+	return ret == GTK_RESPONSE_YES;
 }
 
 static GtkSourceCompressionType
@@ -694,6 +704,14 @@ get_compression_type_from_file (GFile *file)
 	return type;
 }
 
+static void
+save_finish_cb (GeditTab     *tab,
+		GAsyncResult *result,
+		gpointer      user_data)
+{
+	_gedit_tab_save_finish (tab, result);
+}
+
 static void
 save_dialog_response_cb (GeditFileChooserDialog *dialog,
                          gint                    response_id,
@@ -738,7 +756,9 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		if ((compression_type == GTK_SOURCE_COMPRESSION_TYPE_NONE) !=
 		    (current_compression_type == GTK_SOURCE_COMPRESSION_TYPE_NONE))
 		{
-			if (!change_compression (GTK_WINDOW (dialog),
+			GtkWindow *dialog_window = gedit_file_chooser_dialog_get_window (dialog);
+
+			if (!change_compression (dialog_window,
 			                         location,
 			                         compression_type != GTK_SOURCE_COMPRESSION_TYPE_NONE))
 			{
@@ -766,11 +786,17 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 		g_free (parse_name);
 
-		/* let's remember the dir we navigated too,
-		 * even if the saving fails... */
+		/* Let's remember the dir we navigated to, even if the saving fails... */
 		_gedit_window_set_default_location (window, location);
 
-		_gedit_tab_save_as (tab, location, encoding, newline_type, compression_type);
+		_gedit_tab_save_as_async (tab,
+					  location,
+					  encoding,
+					  newline_type,
+					  compression_type,
+					  NULL,
+					  (GAsyncReadyCallback) save_finish_cb,
+					  NULL);
 
 		g_object_unref (location);
 	}
@@ -780,7 +806,9 @@ save_next_tab:
 	data = g_object_get_data (G_OBJECT (window),
 				  GEDIT_LIST_OF_TABS_TO_SAVE_AS);
 	if (data == NULL)
+	{
 		return;
+	}
 
 	/* Save As the next tab of the list (we are Saving All files) */
 	tabs_to_save_as = (GSList *)data;
@@ -799,7 +827,7 @@ save_next_tab:
 		tab = GEDIT_TAB (tabs_to_save_as->data);
 
 		if (GPOINTER_TO_BOOLEAN (g_object_get_data (G_OBJECT (tab),
-							    GEDIT_IS_CLOSING_TAB)) == TRUE)
+							    GEDIT_IS_CLOSING_TAB)))
 		{
 			g_object_set_data (G_OBJECT (tab),
 					   GEDIT_IS_CLOSING_TAB,
@@ -813,7 +841,7 @@ save_next_tab:
 		}
 
 		gedit_window_set_active_tab (window, tab);
-		_gedit_cmd_file_save_as_tab (tab, window);
+		save_as_tab (tab, window);
 	}
 }
 
@@ -854,18 +882,18 @@ confirm_overwrite_callback (GeditFileChooserDialog *dialog,
 	return res;
 }
 
-void
-_gedit_cmd_file_save_as_tab (GeditTab    *tab,
-                             GeditWindow *window)
+static void
+save_as_tab (GeditTab    *tab,
+	     GeditWindow *window)
 {
 	GeditFileChooserDialog *save_dialog;
-	GtkWindowGroup *wg;
+	GtkWindowGroup *window_group;
+	GtkWindow *dialog_window;
 	GeditDocument *doc;
 	GtkSourceFile *file;
 	GFile *location;
 	const GtkSourceEncoding *encoding;
 	GtkSourceNewlineType newline_type;
-	GtkWindow *win;
 
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 	g_return_if_fail (GEDIT_IS_WINDOW (window));
@@ -889,13 +917,13 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 			  G_CALLBACK (confirm_overwrite_callback),
 			  NULL);
 
-	wg = gedit_window_get_group (window);
+	window_group = gedit_window_get_group (window);
 
-	win = gedit_file_chooser_dialog_get_window (save_dialog);
+	dialog_window = gedit_file_chooser_dialog_get_window (save_dialog);
 
-	if (win != NULL)
+	if (dialog_window != NULL)
 	{
-		gtk_window_group_add_window (wg, win);
+		gtk_window_group_add_window (window_group, dialog_window);
 	}
 
 	/* Save As dialog is modal to its main window */
@@ -960,9 +988,9 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 	gedit_file_chooser_dialog_show (save_dialog);
 }
 
-void
-_gedit_cmd_file_save_tab (GeditTab    *tab,
-                          GeditWindow *window)
+static void
+save_tab (GeditTab    *tab,
+	  GeditWindow *window)
 {
 	GeditDocument *doc;
 	gchar *uri_for_display;
@@ -979,9 +1007,7 @@ _gedit_cmd_file_save_tab (GeditTab    *tab,
 	    gedit_document_get_readonly (doc))
 	{
 		gedit_debug_message (DEBUG_COMMANDS, "Untitled or Readonly");
-
-		_gedit_cmd_file_save_as_tab (tab, window);
-
+		save_as_tab (tab, window);
 		return;
 	}
 
@@ -993,7 +1019,10 @@ _gedit_cmd_file_save_tab (GeditTab    *tab,
 
 	g_free (uri_for_display);
 
-	_gedit_tab_save (tab);
+	_gedit_tab_save_async (tab,
+			       NULL,
+			       (GAsyncReadyCallback) save_finish_cb,
+			       NULL);
 }
 
 void
@@ -1007,10 +1036,10 @@ _gedit_cmd_file_save (GSimpleAction *action,
 	gedit_debug (DEBUG_COMMANDS);
 
 	tab = gedit_window_get_active_tab (window);
-	if (tab == NULL)
-		return;
-
-	_gedit_cmd_file_save_tab (tab, window);
+	if (tab != NULL)
+	{
+		save_tab (tab, window);
+	}
 }
 
 void
@@ -1024,47 +1053,45 @@ _gedit_cmd_file_save_as (GSimpleAction *action,
 	gedit_debug (DEBUG_COMMANDS);
 
 	tab = gedit_window_get_active_tab (window);
-	if (tab == NULL)
-		return;
-
-	_gedit_cmd_file_save_as_tab (tab, window);
+	if (tab != NULL)
+	{
+		save_as_tab (tab, window);
+	}
 }
 
 /*
  * The docs in the list must belong to the same GeditWindow.
  */
-void
-_gedit_cmd_file_save_documents_list (GeditWindow *window,
-				     GList       *docs)
+static void
+save_documents_list (GeditWindow *window,
+		     GList       *docs)
 {
 	GList *l;
 	GSList *tabs_to_save_as = NULL;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	g_return_if_fail (!(gedit_window_get_state (window) &
-			    GEDIT_WINDOW_STATE_PRINTING));
+	g_return_if_fail ((gedit_window_get_state (window) & GEDIT_WINDOW_STATE_PRINTING) == 0);
 
-	l = docs;
-	while (l != NULL)
+	for (l = docs; l != NULL; l = l->next)
 	{
 		GeditDocument *doc;
-		GeditTab *t;
+		GeditTab *tab;
 		GeditTabState state;
 
 		g_return_if_fail (GEDIT_IS_DOCUMENT (l->data));
+		doc = l->data;
 
-		doc = GEDIT_DOCUMENT (l->data);
-		t = gedit_tab_get_from_document (doc);
-		state = gedit_tab_get_state (t);
+		tab = gedit_tab_get_from_document (doc);
+		state = gedit_tab_get_state (tab);
 
 		g_return_if_fail (state != GEDIT_TAB_STATE_PRINTING);
 		g_return_if_fail (state != GEDIT_TAB_STATE_PRINT_PREVIEWING);
 		g_return_if_fail (state != GEDIT_TAB_STATE_CLOSING);
 
-		if ((state == GEDIT_TAB_STATE_NORMAL) ||
-		    (state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW) ||
-		    (state == GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE))
+		if (state == GEDIT_TAB_STATE_NORMAL ||
+		    state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW ||
+		    state == GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE)
 		{
 			if (_gedit_document_needs_saving (doc))
 			{
@@ -1073,12 +1100,11 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 				if (gedit_document_is_untitled (doc) ||
 				    gedit_document_get_readonly (doc))
 				{
-					tabs_to_save_as = g_slist_prepend (tabs_to_save_as,
-									   t);
+					tabs_to_save_as = g_slist_prepend (tabs_to_save_as, tab);
 				}
 				else
 				{
-					_gedit_cmd_file_save_tab (t, window);
+					save_tab (tab, window);
 				}
 			}
 		}
@@ -1114,15 +1140,13 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 					     state);
 			g_free (uri_for_display);
 		}
-
-		l = g_list_next (l);
 	}
 
 	if (tabs_to_save_as != NULL)
 	{
 		GeditTab *tab;
 
-		tabs_to_save_as = g_slist_reverse (tabs_to_save_as );
+		tabs_to_save_as = g_slist_reverse (tabs_to_save_as);
 
 		g_return_if_fail (g_object_get_data (G_OBJECT (window),
 						     GEDIT_LIST_OF_TABS_TO_SAVE_AS) == NULL);
@@ -1134,7 +1158,7 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 		tab = GEDIT_TAB (tabs_to_save_as->data);
 
 		gedit_window_set_active_tab (window, tab);
-		_gedit_cmd_file_save_as_tab (tab, window);
+		save_as_tab (tab, window);
 	}
 }
 
@@ -1149,7 +1173,7 @@ gedit_commands_save_all_documents (GeditWindow *window)
 
 	docs = gedit_window_get_documents (window);
 
-	_gedit_cmd_file_save_documents_list (window, docs);
+	save_documents_list (window, docs);
 
 	g_list_free (docs);
 }
@@ -1174,7 +1198,7 @@ gedit_commands_save_document (GeditWindow   *window,
 	gedit_debug (DEBUG_COMMANDS);
 
 	tab = gedit_tab_get_from_document (document);
-	_gedit_cmd_file_save_tab (tab, window);
+	save_tab (tab, window);
 }
 
 /* File revert */
@@ -1191,7 +1215,7 @@ do_revert (GeditWindow *window,
 	docname = gedit_document_get_short_name_for_display (doc);
 
 	gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-				        window->priv->generic_message_cid,
+				       window->priv->generic_message_cid,
 				       _("Reverting the document '%s'\342\200\246"),
 				       docname);
 
@@ -1214,7 +1238,9 @@ revert_dialog_response_cb (GtkDialog   *dialog,
 	   not very nice - Paolo (Oct 11, 2005) */
 	tab = gedit_window_get_active_tab (window);
 	if (tab == NULL)
+	{
 		return;
+	}
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
@@ -1344,21 +1370,21 @@ _gedit_cmd_file_revert (GSimpleAction *action,
                         GVariant      *parameter,
                         gpointer       user_data)
 {
-	GeditWindow    *window = GEDIT_WINDOW (user_data);
-	GeditTab       *tab;
-	GeditDocument  *doc;
-	GtkWidget      *dialog;
-	GtkWindowGroup *wg;
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+	GeditTab *tab;
+	GeditDocument *doc;
+	GtkWidget *dialog;
+	GtkWindowGroup *window_group;
 
 	gedit_debug (DEBUG_COMMANDS);
 
 	tab = gedit_window_get_active_tab (window);
 	g_return_if_fail (tab != NULL);
 
-	/* If we are already displaying a notification
-	 * reverting will drop local modifications or
-	 * if the document has not been modified, do
-	 * not bug the user further */
+	/* If we are already displaying a notification reverting will drop local
+	 * modifications or if the document has not been modified, do not bug
+	 * the user further.
+	 */
 	if (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION ||
 	    _gedit_tab_get_can_close (tab))
 	{
@@ -1372,9 +1398,9 @@ _gedit_cmd_file_revert (GSimpleAction *action,
 
 	dialog = revert_dialog (window, doc);
 
-	wg = gedit_window_get_group (window);
+	window_group = gedit_window_get_group (window);
 
-	gtk_window_group_add_window (wg, GTK_WINDOW (dialog));
+	gtk_window_group_add_window (window_group, GTK_WINDOW (dialog));
 
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
@@ -1399,7 +1425,9 @@ quit_if_needed (GeditWindow *window)
 							          GEDIT_IS_QUITTING_ALL));
 
 	if (is_quitting)
+	{
 		gtk_widget_destroy (GTK_WIDGET (window));
+	}
 
 	if (is_quitting_all)
 	{
@@ -1446,15 +1474,16 @@ tab_state_changed_while_saving (GeditTab    *tab,
 				GParamSpec  *pspec,
 				GeditWindow *window)
 {
-	GeditTabState ts;
+	GeditTabState state;
 
-	ts = gedit_tab_get_state (tab);
+	state = gedit_tab_get_state (tab);
 
-	gedit_debug_message (DEBUG_COMMANDS, "State while saving: %d\n", ts);
+	gedit_debug_message (DEBUG_COMMANDS, "State while saving: %d\n", state);
 
-	/* When the state become NORMAL, it means the saving operation is
-	   finished */
-	if (ts == GEDIT_TAB_STATE_NORMAL)
+	/* When the state becomes NORMAL, it means the saving operation is
+	 * finished.
+	 */
+	if (state == GEDIT_TAB_STATE_NORMAL)
 	{
 		GeditDocument *doc;
 
@@ -1466,13 +1495,17 @@ tab_state_changed_while_saving (GeditTab    *tab,
 		g_return_if_fail (doc != NULL);
 
 		/* If the saving operation failed or was interrupted, then the
-		   document is still "modified" -> do not close the tab */
+		 * document is still "modified" -> do not close the tab.
+		 */
 		if (_gedit_document_needs_saving (doc))
+		{
 			return;
+		}
 
 		/* Close the document only if it has been succesfully saved.
-		   Tab state is set to CLOSING (it is a state without exiting
-		   transitions) and the tab is closed in a idle handler */
+		 * Tab state is set to CLOSING (it is a state without exiting
+		 * transitions) and the tab is closed in an idle handler.
+		 */
 		_gedit_tab_mark_for_closing (tab);
 
 		g_idle_add_full (G_PRIORITY_HIGH_IDLE,
@@ -1494,7 +1527,7 @@ save_and_close (GeditTab    *tab,
 			  G_CALLBACK (tab_state_changed_while_saving),
 			  window);
 
-	_gedit_cmd_file_save_tab (tab, window);
+	save_tab (tab, window);
 }
 
 static void
@@ -1514,7 +1547,7 @@ save_as_and_close (GeditTab    *tab,
 			  window);
 
 	gedit_window_set_active_tab (window, tab);
-	_gedit_cmd_file_save_as_tab (tab, window);
+	save_as_tab (tab, window);
 }
 
 static void
@@ -1525,13 +1558,13 @@ save_and_close_documents (GList         *docs,
 	GList *tabs;
 	GList *l;
 	GSList *sl;
-	GSList *tabs_to_save_as;
-	GSList *tabs_to_save_and_close;
-	GList *tabs_to_close;
+	GSList *tabs_to_save_as = NULL;
+	GSList *tabs_to_save_and_close = NULL;
+	GList *tabs_to_close = NULL;
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	g_return_if_fail (!(gedit_window_get_state (window) & GEDIT_WINDOW_STATE_PRINTING));
+	g_return_if_fail ((gedit_window_get_state (window) & GEDIT_WINDOW_STATE_PRINTING) == 0);
 
 	if (notebook != NULL)
 	{
@@ -1542,21 +1575,14 @@ save_and_close_documents (GList         *docs,
 		tabs = _gedit_window_get_all_tabs (window);
 	}
 
-	tabs_to_save_as = NULL;
-	tabs_to_save_and_close = NULL;
-	tabs_to_close = NULL;
-
-	l = tabs;
-	while (l != NULL)
+	for (l = tabs; l != NULL; l = l->next)
 	{
-		GeditTab *t;
+		GeditTab *tab = GEDIT_TAB (l->data);
 		GeditTabState state;
 		GeditDocument *doc;
 
-		t = GEDIT_TAB (l->data);
-
-		state = gedit_tab_get_state (t);
-		doc = gedit_tab_get_document (t);
+		state = gedit_tab_get_state (tab);
+		doc = gedit_tab_get_document (tab);
 
 		/* If the state is: ([*] invalid states)
 		   - GEDIT_TAB_STATE_NORMAL: close (and if needed save)
@@ -1587,45 +1613,40 @@ save_and_close_documents (GList         *docs,
 		g_return_if_fail (state != GEDIT_TAB_STATE_CLOSING);
 		g_return_if_fail (state != GEDIT_TAB_STATE_SAVING);
 
-		if ((state != GEDIT_TAB_STATE_SAVING_ERROR) &&
-		    (state != GEDIT_TAB_STATE_GENERIC_ERROR) &&
-		    (state != GEDIT_TAB_STATE_REVERTING_ERROR))
+		if (state != GEDIT_TAB_STATE_SAVING_ERROR &&
+		    state != GEDIT_TAB_STATE_GENERIC_ERROR &&
+		    state != GEDIT_TAB_STATE_REVERTING_ERROR)
 		{
-			if ((g_list_index ((GList *)docs, doc) >= 0) &&
-			    (state != GEDIT_TAB_STATE_LOADING) &&
-			    (state != GEDIT_TAB_STATE_LOADING_ERROR) &&
-			    (state != GEDIT_TAB_STATE_REVERTING)) /* CHECK: is this the right behavior with REVERTING ?*/
+			if (g_list_index (docs, doc) >= 0 &&
+			    state != GEDIT_TAB_STATE_LOADING &&
+			    state != GEDIT_TAB_STATE_LOADING_ERROR &&
+			    state != GEDIT_TAB_STATE_REVERTING) /* FIXME: is this the right behavior with REVERTING ?*/
 			{
 				/* The document must be saved before closing */
 				g_return_if_fail (_gedit_document_needs_saving (doc));
 
 				/* FIXME: manage the case of local readonly files owned by the
-				   user is running gedit - Paolo (Dec. 8, 2005) */
+				 * user is running gedit - Paolo (Dec. 8, 2005) */
 				if (gedit_document_is_untitled (doc) ||
 				    gedit_document_get_readonly (doc))
 				{
-					g_object_set_data (G_OBJECT (t),
+					g_object_set_data (G_OBJECT (tab),
 							   GEDIT_IS_CLOSING_TAB,
 							   GBOOLEAN_TO_POINTER (TRUE));
 
-					tabs_to_save_as = g_slist_prepend (tabs_to_save_as,
-									   t);
+					tabs_to_save_as = g_slist_prepend (tabs_to_save_as, tab);
 				}
 				else
 				{
-					tabs_to_save_and_close = g_slist_prepend (tabs_to_save_and_close,
-										  t);
+					tabs_to_save_and_close = g_slist_prepend (tabs_to_save_and_close, tab);
 				}
 			}
 			else
 			{
-				/* The document must be closed without saving */
-				tabs_to_close = g_list_prepend (tabs_to_close,
-								t);
+				/* The document can be closed without saving */
+				tabs_to_close = g_list_prepend (tabs_to_close, tab);
 			}
 		}
-
-		l = g_list_next (l);
 	}
 
 	g_list_free (tabs);
@@ -1635,13 +1656,11 @@ save_and_close_documents (GList         *docs,
 	g_list_free (tabs_to_close);
 
 	/* Save and close all the files in tabs_to_save_and_close */
-	sl = tabs_to_save_and_close;
-	while (sl != NULL)
+	for (sl = tabs_to_save_and_close; sl != NULL; sl = sl->next)
 	{
-		save_and_close (GEDIT_TAB (sl->data),
-				window);
-		sl = g_slist_next (sl);
+		save_and_close (GEDIT_TAB (sl->data), window);
 	}
+
 	g_slist_free (tabs_to_save_and_close);
 
 	/* Save As and close all the files in tabs_to_save_as  */
@@ -1649,7 +1668,7 @@ save_and_close_documents (GList         *docs,
 	{
 		GeditTab *tab;
 
-		tabs_to_save_as = g_slist_reverse (tabs_to_save_as );
+		tabs_to_save_as = g_slist_reverse (tabs_to_save_as);
 
 		g_return_if_fail (g_object_get_data (G_OBJECT (window),
 						     GEDIT_LIST_OF_TABS_TO_SAVE_AS) == NULL);
@@ -1665,8 +1684,8 @@ save_and_close_documents (GList         *docs,
 }
 
 static void
-save_and_close_document (const GList  *docs,
-			 GeditWindow  *window)
+save_and_close_document (const GList *docs,
+			 GeditWindow *window)
 {
 	GeditTab *tab;
 
@@ -1725,7 +1744,8 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 
 	switch (response_id)
 	{
-		case GTK_RESPONSE_YES: /* Save and Close */
+		/* Save and Close */
+		case GTK_RESPONSE_YES:
 			selected_documents = gedit_close_confirmation_dialog_get_selected_documents (dlg);
 
 			if (selected_documents == NULL)
@@ -1738,7 +1758,6 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 					gtk_widget_destroy (GTK_WIDGET (dlg));
 
 					close_all_tabs (window);
-
 					return;
 				}
 				else if (notebook_to_close)
@@ -1754,9 +1773,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			{
 				if (is_closing_all || notebook_to_close)
 				{
-					GeditNotebook *nb = is_closing_all ? NULL : notebook_to_close;
+					GeditNotebook *notebook = is_closing_all ? NULL : notebook_to_close;
 
-					save_and_close_documents (selected_documents, window, nb);
+					save_and_close_documents (selected_documents, window, notebook);
 				}
 				else
 				{
@@ -1765,10 +1784,10 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			}
 
 			g_list_free (selected_documents);
-
 			break;
 
-		case GTK_RESPONSE_NO: /* Close without Saving */
+		/* Close without Saving */
+		case GTK_RESPONSE_NO:
 			if (is_closing_all)
 			{
 				/* We call gtk_widget_destroy before close_all_tabs
@@ -1776,7 +1795,6 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 				gtk_widget_destroy (GTK_WIDGET (dlg));
 
 				close_all_tabs (window);
-
 				return;
 			}
 			else if (notebook_to_close)
@@ -1795,8 +1813,8 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 
 			break;
 
-		default: /* Do not close */
-
+		/* Do not close */
+		default:
 			/* Reset is_quitting flag */
 			g_object_set_data (G_OBJECT (window),
 			                   GEDIT_IS_QUITTING,
@@ -1842,7 +1860,7 @@ tab_can_close (GeditTab  *tab,
 	return TRUE;
 }
 
-/* CHECK: we probably need this one public for plugins...
+/* FIXME: we probably need this one public for plugins...
  * maybe even a _list variant. Or maybe it's better make
  * gedit_window_close_tab always run the confirm dialog?
  * we should not allow closing a tab without resetting the
@@ -1904,7 +1922,7 @@ file_close_dialog (GeditWindow *window,
 	if (unsaved_docs->next == NULL)
 	{
 		/* There is only one unsaved document */
-		GeditTab      *tab;
+		GeditTab *tab;
 		GeditDocument *doc;
 
 		doc = GEDIT_DOCUMENT (unsaved_docs->data);
@@ -1932,18 +1950,21 @@ file_close_dialog (GeditWindow *window,
 static GList *
 notebook_get_unsaved_documents (GeditNotebook *notebook)
 {
-	GList *children, *l;
+	GList *children;
 	GList *unsaved_docs = NULL;
+	GList *l;
 
 	children = gtk_container_get_children (GTK_CONTAINER (notebook));
 
 	for (l = children; l != NULL; l = g_list_next (l))
 	{
-		if (!_gedit_tab_get_can_close (l->data))
+		GeditTab *tab = GEDIT_TAB (l->data);
+
+		if (!_gedit_tab_get_can_close (tab))
 		{
 			GeditDocument *doc;
 
-			doc = gedit_tab_get_document (l->data);
+			doc = gedit_tab_get_document (tab);
 			unsaved_docs = g_list_prepend (unsaved_docs, doc);
 		}
 	}
@@ -1986,7 +2007,7 @@ static void
 file_close_all (GeditWindow *window,
                 gboolean     is_quitting)
 {
-	GList     *unsaved_docs;
+	GList *unsaved_docs;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -2028,8 +2049,8 @@ _gedit_cmd_file_close_all (GSimpleAction *action,
 	gedit_debug (DEBUG_COMMANDS);
 
 	g_return_if_fail (!(gedit_window_get_state (window) &
-	                    (GEDIT_WINDOW_STATE_SAVING |
-	                    GEDIT_WINDOW_STATE_PRINTING)));
+			    (GEDIT_WINDOW_STATE_SAVING |
+			     GEDIT_WINDOW_STATE_PRINTING)));
 
 	file_close_all (window, FALSE);
 }
